declare module "esbuild-dev-server" {
    /**
    * Dev server options.
    * @type {string} port start local server
    * @type {string} Root html file
    * @type {string} Stacic files
    * @type {string} Working directory
    * @type {() => void} Event before rebuild
    * @type {() => void} Event after rebuild
    */
    export interface DevServerOptions {
        port: string;
        index: string;
        staticDir: string;
        watchDir: string;
        onBeforeRebuild: () => void;
        onAfterRebuild: () => void;
    }
    /**
    * Send error dev server.
    * @param {string} message Message to dev server.
    * @return {Promise<Error | null>}
    */
    export const sendError: (message: string) => Promise<Error | null>;
    /**
    * Send reload dev server.
    * @return {Promise<Error | null>}
    */
    export const sendReload: () => Promise<Error | null>;
    /**
    * Set dev server options for esbuild.
    * @param {Promise<BuildIncremental>} build esbuild options.
    * @param {Promise<DevServerOptions>} options dev-server options.
    */
    export const start: (build: Promise<any>, options: DevServerOptions) => void;
}
